==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicPasswordFieldUI.h <==
// public class javax.swing.plaf.basic.BasicPasswordFieldUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class cb49ffe0ee4d13c javax_swing_plaf_TextUI
// @dep_class ee3d35b29d690c85 javax_swing_plaf_basic_BasicPasswordFieldUI
// @dep_class c96b86492c177195 javax_swing_plaf_basic_BasicTextFieldUI
// @dep_class d214d118732d43a9 javax_swing_plaf_basic_BasicTextUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTextFieldUI

#include "javax/swing/plaf/basic/BasicTextFieldUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicPasswordFieldUI_H_
#define _JC_javax_swing_plaf_basic_BasicPasswordFieldUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_refs	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$refs	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$nonrefs	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vmethods	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtable	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtype	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object *);

// Virtual methods
extern struct _jc_javax_swing_text_View$object *_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method$create$cf4235120765a02e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method_info$create$cf4235120765a02e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method_info$getPropertyPrefix$e7baa4035901c9a7;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vmethods {
	struct _jc_javax_swing_text_View$object	*(*create$cf4235120765a02e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TextUI$vmethods	javax_swing_plaf_TextUI;
	_jc_javax_swing_plaf_basic_BasicTextUI$vmethods	javax_swing_plaf_basic_BasicTextUI;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods	javax_swing_plaf_basic_BasicTextFieldUI;
	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vmethods	javax_swing_plaf_basic_BasicPasswordFieldUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$refs {
    _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_refs	javax_swing_plaf_basic_BasicPasswordFieldUI;
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs	javax_swing_plaf_basic_BasicTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_refs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_TextUI$sub_refs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TextUI$sub_nonrefs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_nonrefs	javax_swing_plaf_basic_BasicPasswordFieldUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object {
	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtype _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicPasswordFieldUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicPasswordFieldUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicPasswordFieldUI.h <==
// public class javax.swing.plaf.basic.BasicPasswordFieldUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class cb49ffe0ee4d13c javax_swing_plaf_TextUI
// @dep_class ee3d35b29d690c85 javax_swing_plaf_basic_BasicPasswordFieldUI
// @dep_class c96b86492c177195 javax_swing_plaf_basic_BasicTextFieldUI
// @dep_class d214d118732d43a9 javax_swing_plaf_basic_BasicTextUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTextFieldUI

#include "javax/swing/plaf/basic/BasicTextFieldUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicPasswordFieldUI_H_
#define _JC_javax_swing_plaf_basic_BasicPasswordFieldUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_refs	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$refs	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$nonrefs	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vmethods	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtable	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtype	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_text_View$object *_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method$create$cf4235120765a02e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method_info$create$cf4235120765a02e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method_info$getPropertyPrefix$e7baa4035901c9a7;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vmethods {
	struct _jc_javax_swing_text_View$object	*(*create$cf4235120765a02e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TextUI$vmethods	javax_swing_plaf_TextUI;
	_jc_javax_swing_plaf_basic_BasicTextUI$vmethods	javax_swing_plaf_basic_BasicTextUI;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods	javax_swing_plaf_basic_BasicTextFieldUI;
	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vmethods	javax_swing_plaf_basic_BasicPasswordFieldUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$refs {
    _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_refs	javax_swing_plaf_basic_BasicPasswordFieldUI;
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs	javax_swing_plaf_basic_BasicTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_refs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_TextUI$sub_refs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TextUI$sub_nonrefs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$sub_nonrefs	javax_swing_plaf_basic_BasicPasswordFieldUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$object {
	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicPasswordFieldUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$vtype _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicPasswordFieldUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicPasswordFieldUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicPasswordFieldUI_H_ */
